@@ -121,7 +121,9 @@ static const TEXT gdslogid[] = "";
 
 #ifdef WIN_NT
 #include <shlobj.h>
+#if _MSC_VER <= 1500
 #include <shfolder.h>
+#endif
 #define _WINSOCKAPI_
 #include <share.h>
 #include "err_proto.h"
@@ -200,8 +202,6 @@ static int		blr_print_word(gds_ctl*);
 
 static void		sanitize(Firebird::string& locale);
 
-static void		safe_concat_path(TEXT* destbuf, const TEXT* srcbuf);
-
 // New functions that try to be safe.
 static SLONG safe_interpret(char* const s, const size_t bufsize,
 	const ISC_STATUS** const vector, bool legacy = false);
@@ -1734,7 +1734,7 @@ void API_ROUTINE gds__prefix(TEXT* resultString, const TEXT* file)
 	GDS_init_prefix();
 
 	strcpy(resultString, fb_prefix);	// safe - no BO
-	safe_concat_path(resultString, file);
+	iscSafeConcatPath(resultString, file);
 }
 
 
@@ -1755,12 +1755,7 @@ void API_ROUTINE gds__prefix_lock(TEXT* string, const TEXT* root)
 	GDS_init_prefix();
 
 	strcpy(string, fb_prefix_lock);	// safe - no BO
-
-	// if someone wants to know prefix for lock files,
-	// sooner of all he wants that directory to exist
-	os_utils::createLockDirectory(string);
-
-	safe_concat_path(string, root);
+	iscSafeConcatPath(string, root);
 }
 
 
@@ -1784,7 +1779,7 @@ void API_ROUTINE gds__prefix_msg(TEXT* string, const TEXT* root)
 	GDS_init_prefix();
 
 	strcpy(string, fb_prefix_msg);	// safe - no BO
-	safe_concat_path(string, root);
+	iscSafeConcatPath(string, root);
 }
 
 
@@ -3081,6 +3076,14 @@ static int blr_print_dtype(gds_ctl* control)
 			// 0 = blr_domain_type_of; 1 = blr_domain_full
 			blr_print_byte(control);
 
+			if (dtype == blr_column_name || dtype == blr_column_name2)
+			{
+				for (UCHAR n = blr_print_byte(control); n > 0; --n)
+					blr_print_char(control);
+
+				blr_format(control, " ");
+			}
+
 			for (UCHAR n = blr_print_byte(control); n > 0; --n)
 				blr_print_char(control);
 
@@ -3553,43 +3556,6 @@ static void sanitize(Firebird::string& locale)
 	}
 }
 
-static void safe_concat_path(TEXT *resultString, const TEXT *appendString)
-{
-/**************************************
- *
- *	s a f e _ c o n c a t _ p a t h
- *
- **************************************
- *
- * Functional description
- *	Safely appends appendString to resultString using paths rules.
- *  resultString must be at most MAXPATHLEN size.
- *	Thread/signal safe code.
- *
- **************************************/
-	size_t len = strlen(resultString);
-	fb_assert(len > 0);
-
-	if (resultString[len - 1] != PathUtils::dir_sep && len < MAXPATHLEN - 1)
-	{
-		resultString[len++] = PathUtils::dir_sep;
-		resultString[len] = 0;
-	}
-
-	size_t alen = strlen(appendString);
-	if (len + alen > MAXPATHLEN - 1)
-	{
-		alen = MAXPATHLEN - 1 - len;
-	}
-
-	fb_assert(len < MAXPATHLEN);
-	fb_assert(alen < MAXPATHLEN);
-	fb_assert(len + alen < MAXPATHLEN);
-
-	memcpy(&resultString[len], appendString, alen);
-	resultString[len + alen] = 0;
-}
-
 
 void FB_EXPORTED gds__default_printer(void* /*arg*/, SSHORT offset, const TEXT* line)
 {
